==> hazelcast-5.1-sources.jar: com/hazelcast/internal/config/ExecutorConfigReadOnly.java <==
/*
 * Copyright (c) 2008-2022, Hazelcast, Inc. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.hazelcast.internal.config;

import com.hazelcast.config.ExecutorConfig;

/**
 * Configuration for Executor(Read Only)
 */
public class ExecutorConfigReadOnly extends ExecutorConfig {

    public ExecutorConfigReadOnly(ExecutorConfig config) {
        super(config);
    }

    @Override
    public ExecutorConfig setName(String name) {
        throw new UnsupportedOperationException("This config is read-only executor: " + getName());
    }

    @Override
    public ExecutorConfig setPoolSize(int poolSize) {
        throw new UnsupportedOperationException("This config is read-only executor: " + getName());
    }

    @Override
    public ExecutorConfig setQueueCapacity(int queueCapacity) {
        throw new UnsupportedOperationException("This config is read-only executor: " + getName());
    }

    @Override
    public ExecutorConfig setStatisticsEnabled(boolean statisticsEnabled) {
        throw new UnsupportedOperationException("This config is read-only executor: " + getName());
    }

    @Override
    public ExecutorConfig setSplitBrainProtectionName(String splitBrainProtectionName) {
        throw new UnsupportedOperationException("This config is read-only executor: " + getName());
    }
}

==> hazelcast-5.6.0-sources.jar: com/hazelcast/internal/config/ExecutorConfigReadOnly.java <==
/*
 * Copyright (c) 2008-2025, Hazelcast, Inc. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.hazelcast.internal.config;

import com.hazelcast.config.ExecutorConfig;

import javax.annotation.Nullable;

/**
 * Configuration for Executor(Read Only)
 */
public class ExecutorConfigReadOnly extends ExecutorConfig {

    public ExecutorConfigReadOnly(ExecutorConfig config) {
        super(config);
    }

    @Override
    public ExecutorConfig setName(String name) {
        throw new UnsupportedOperationException("This config is read-only executor: " + getName());
    }

    @Override
    public ExecutorConfig setPoolSize(int poolSize) {
        throw new UnsupportedOperationException("This config is read-only executor: " + getName());
    }

    @Override
    public ExecutorConfig setQueueCapacity(int queueCapacity) {
        throw new UnsupportedOperationException("This config is read-only executor: " + getName());
    }

    @Override
    public ExecutorConfig setStatisticsEnabled(boolean statisticsEnabled) {
        throw new UnsupportedOperationException("This config is read-only executor: " + getName());
    }

    @Override
    public ExecutorConfig setSplitBrainProtectionName(String splitBrainProtectionName) {
        throw new UnsupportedOperationException("This config is read-only executor: " + getName());
    }

    @Override
    public ExecutorConfig setUserCodeNamespace(@Nullable String userCodeNamespace) {
        throw new UnsupportedOperationException("This config is read-only executor: " + getName());
    }
}
